# Test summary

Compare to:

### test_run: 3feb_effstim_r802

### project: syn_pysyn

### host: gaudete

attributes same for all rows:

tda_etcid | None
tda_form | vegamag
tda_sigthresh | 0.01
tda_skylines | False
tda_spectrum | crcalspec$alpha_lyr_stis_003.fits
tda_superthresh | 0.2
tda_thresh | 0.01
tra_discrep | -1.0
tra_extreme | True
tra_pysyn | 0.0

test_name | contact | diff | other | stat | tda_obsmode | tra_syn
--- | --- | --- | --- | --- | --- | ---
acs_effstim_cases/testeffstim/E100vegamag | unknown |  |  | F | acs,hrc,f475w | 3.84765407944e-05
acs_effstim_cases/testeffstim/E101vegamag | unknown |  |  | F | acs,hrc,f555w | -1.6973935999e-05
acs_effstim_cases/testeffstim/E102vegamag | unknown |  |  | F | acs,hrc,f606w | 4.00334965889e-06
acs_effstim_cases/testeffstim/E103vegamag | unknown |  |  | F | acs,hrc,f775w | -2.3321932531e-05
acs_effstim_cases/testeffstim/E104vegamag | unknown |  |  | F | acs,hrc,f814w | -1.68962542375e-05
acs_effstim_cases/testeffstim/E105vegamag | unknown |  |  | F | acs,hrc,f850lp | 1.34157280627e-05
acs_effstim_cases/testeffstim/E10vegamag | unknown |  |  | F | acs,wfc1,f475w | 4.18968120357e-05
acs_effstim_cases/testeffstim/E114vegamag | unknown |  |  | F | acs,hrc,f435w | 7.3615963629e-05
acs_effstim_cases/testeffstim/E115vegamag | unknown |  |  | F | acs,hrc,f475w | 3.84765407944e-05
acs_effstim_cases/testeffstim/E116vegamag | unknown |  |  | F | acs,hrc,f555w | -1.6973935999e-05
acs_effstim_cases/testeffstim/E117vegamag | unknown |  |  | F | acs,hrc,f606w | 4.00334965889e-06
acs_effstim_cases/testeffstim/E118vegamag | unknown |  |  | F | acs,hrc,f775w | -2.3321932531e-05
acs_effstim_cases/testeffstim/E119vegamag | unknown |  |  | F | acs,hrc,f814w | -1.68962542375e-05
acs_effstim_cases/testeffstim/E11vegamag | unknown |  |  | F | acs,wfc1,f555w | -1.34360043376e-05
acs_effstim_cases/testeffstim/E120vegamag | unknown |  |  | F | acs,hrc,f850lp | 1.34157280627e-05
acs_effstim_cases/testeffstim/E12vegamag | unknown |  |  | F | acs,wfc1,f606w | 5.47417221242e-06
acs_effstim_cases/testeffstim/E13vegamag | unknown |  |  | F | acs,wfc1,f775w | -2.53261223406e-05
acs_effstim_cases/testeffstim/E14vegamag | unknown |  |  | F | acs,wfc1,f814w | -1.82811818377e-05
acs_effstim_cases/testeffstim/E15vegamag | unknown |  |  | F | acs,wfc1,f850lp | -3.92259171349e-05
acs_effstim_cases/testeffstim/E24vegamag | unknown |  |  | F | acs,wfc1,f435w | -2.06772765523e-05
acs_effstim_cases/testeffstim/E25vegamag | unknown |  |  | F | acs,wfc1,f475w | 4.18968120357e-05
acs_effstim_cases/testeffstim/E26vegamag | unknown |  |  | F | acs,wfc1,f555w | -1.34360043376e-05
acs_effstim_cases/testeffstim/E27vegamag | unknown |  |  | F | acs,wfc1,f606w | 5.47417221242e-06
acs_effstim_cases/testeffstim/E28vegamag | unknown |  |  | F | acs,wfc1,f775w | -2.53261223406e-05
acs_effstim_cases/testeffstim/E29vegamag | unknown |  |  | F | acs,wfc1,f814w | -1.82811818377e-05
acs_effstim_cases/testeffstim/E30vegamag | unknown |  |  | F | acs,wfc1,f850lp | -3.92259171349e-05
acs_effstim_cases/testeffstim/E39vegamag | unknown |  |  | F | acs,wfc1,f435w | -2.06772765523e-05
acs_effstim_cases/testeffstim/E40vegamag | unknown |  |  | F | acs,wfc1,f475w | 4.18968120357e-05
acs_effstim_cases/testeffstim/E41vegamag | unknown |  |  | F | acs,wfc1,f555w | -1.34360043376e-05
acs_effstim_cases/testeffstim/E42vegamag | unknown |  |  | F | acs,wfc1,f606w | 5.47417221242e-06
acs_effstim_cases/testeffstim/E43vegamag | unknown |  |  | F | acs,wfc1,f775w | -2.53261223406e-05
acs_effstim_cases/testeffstim/E44vegamag | unknown |  |  | F | acs,wfc1,f814w | -1.82811818377e-05
acs_effstim_cases/testeffstim/E45vegamag | unknown |  |  | F | acs,wfc1,f850lp | -3.92259171349e-05
acs_effstim_cases/testeffstim/E54vegamag | unknown |  |  | F | acs,wfc1,f435w | -2.06772765523e-05
acs_effstim_cases/testeffstim/E55vegamag | unknown |  |  | F | acs,wfc1,f475w | 4.18968120357e-05
acs_effstim_cases/testeffstim/E56vegamag | unknown |  |  | F | acs,wfc1,f555w | -1.34360043376e-05
acs_effstim_cases/testeffstim/E57vegamag | unknown |  |  | F | acs,wfc1,f606w | 5.47417221242e-06
acs_effstim_cases/testeffstim/E58vegamag | unknown |  |  | F | acs,wfc1,f775w | -2.53261223406e-05
acs_effstim_cases/testeffstim/E59vegamag | unknown |  |  | F | acs,wfc1,f814w | -1.82811818377e-05
acs_effstim_cases/testeffstim/E60vegamag | unknown |  |  | F | acs,wfc1,f850lp | -3.92259171349e-05
acs_effstim_cases/testeffstim/E69vegamag | unknown |  |  | F | acs,hrc,f435w | 7.3615963629e-05
acs_effstim_cases/testeffstim/E70vegamag | unknown |  |  | F | acs,hrc,f475w | 3.84765407944e-05
acs_effstim_cases/testeffstim/E71vegamag | unknown |  |  | F | acs,hrc,f555w | -1.6973935999e-05
acs_effstim_cases/testeffstim/E72vegamag | unknown |  |  | F | acs,hrc,f606w | 4.00334965889e-06
acs_effstim_cases/testeffstim/E73vegamag | unknown |  |  | F | acs,hrc,f775w | -2.3321932531e-05
acs_effstim_cases/testeffstim/E74vegamag | unknown |  |  | F | acs,hrc,f814w | -1.68962542375e-05
acs_effstim_cases/testeffstim/E75vegamag | unknown |  |  | F | acs,hrc,f850lp | 1.34157280627e-05
acs_effstim_cases/testeffstim/E84vegamag | unknown |  |  | F | acs,hrc,f435w | 7.3615963629e-05
acs_effstim_cases/testeffstim/E85vegamag | unknown |  |  | F | acs,hrc,f475w | 3.84765407944e-05
acs_effstim_cases/testeffstim/E86vegamag | unknown |  |  | F | acs,hrc,f555w | -1.6973935999e-05
acs_effstim_cases/testeffstim/E87vegamag | unknown |  |  | F | acs,hrc,f606w | 4.00334965889e-06
acs_effstim_cases/testeffstim/E88vegamag | unknown |  |  | F | acs,hrc,f775w | -2.3321932531e-05
acs_effstim_cases/testeffstim/E89vegamag | unknown |  |  | F | acs,hrc,f814w | -1.68962542375e-05
acs_effstim_cases/testeffstim/E90vegamag | unknown |  |  | F | acs,hrc,f850lp | 1.34157280627e-05
acs_effstim_cases/testeffstim/E99vegamag | unknown |  |  | F | acs,hrc,f435w | 7.3615963629e-05
acs_effstim_cases/testeffstim/E9vegamag | unknown |  |  | F | acs,wfc1,f435w | -2.06772765523e-05

DURATION: 0.473076105118
rows: 56
different: 0
detail of all